==> nextcloud-25.0.12p1.tgz: nextcloud/apps/comments/l10n/ru.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Комментарии",
    "You commented" : "Вы прокомментировали",
    "{author} commented" : "{author} прокомментировал",
    "You commented on %1$s" : "Вы прокомментировали %1$s",
    "You commented on {file}" : "Вы прокомментировали {file}",
    "%1$s commented on %2$s" : "%1$s прокомментировано на %2$s",
    "{author} commented on {file}" : "{author} прокомментировал {file}",
    "<strong>Comments</strong> for files" : "<strong>Комментарии</strong> к файлам",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Вы были упомянуты на \"{file}\", в комментарии пользователя, который с тех пор был удалён",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} упомянул вас в комментарии к \"{file}\".",
    "Files app plugin to add comments to files" : "Модуль приложения «Файлы», позволяющий комментировать файлы",
    "Edit comment" : "Редактировать комментарий",
    "Delete comment" : "Удалить комментарий",
    "Cancel edit" : "Отменить правку",
    "Post comment" : "Опубликовать комментарий",
    "No comments yet, start the conversation!" : "Комментарии отсутствуют, начните обсуждение!",
    "No more messages" : "Сообщений нет",
    "Retry" : "Повторить",
    "Failed to mark comments as read" : "Не удалось пометить комментарии как прочитанные",
    "Unable to load the comments list" : "Невозможно загрузить список комментариев",
    "_1 new comment_::_{unread} new comments_" : ["1 новый комментарий","{unread} новых комментариев","{unread} новых комментариев","{unread} новых комментариев"],
    "Comment" : "Комментарий",
    "An error occurred while trying to edit the comment" : "Попытка редактирования комментария завершилась ошибкой",
    "Comment deleted" : "Комментарий удалён",
    "An error occurred while trying to delete the comment" : "Попытка удаления комментария завершилась ошибкой",
    "An error occurred while trying to create the comment" : "Попытка создания комментария завершилась ошибкой",
    "%1$s commented" : "%1$s прокомментировано",
    "_%n unread comment_::_%n unread comments_" : ["%n непрочитанный комментарий","%n непрочитанных комментариев","%n непрочитанных комментариев","%n непрочитанных комментариев"]
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-26.0.11p1.tgz: nextcloud/apps/comments/l10n/ru.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Комментарии",
    "You commented" : "Вы прокомментировали",
    "{author} commented" : "{author} прокомментировал",
    "You commented on %1$s" : "Вы прокомментировали %1$s",
    "You commented on {file}" : "Вы прокомментировали {file}",
    "%1$s commented on %2$s" : "%1$s прокомментировано на %2$s",
    "{author} commented on {file}" : "{author} прокомментировал {file}",
    "<strong>Comments</strong> for files" : "<strong>Комментарии</strong> к файлам",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Вы были упомянуты на \"{file}\", в комментарии пользователя, который с тех пор был удалён",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} упомянул вас в комментарии к \"{file}\".",
    "Files app plugin to add comments to files" : "Модуль приложения «Файлы», позволяющий комментировать файлы",
    "Edit comment" : "Редактировать комментарий",
    "Delete comment" : "Удалить комментарий",
    "Cancel edit" : "Отменить правку",
    "Post comment" : "Опубликовать комментарий",
    "@ for mentions, : for emoji, / for smart picker" : "@ для упоминаний, : для эмодзи, / для интеллектуального выбора",
    "Could not reload comments" : "Не удалось перезагрузить комментарии",
    "No comments yet, start the conversation!" : "Комментарии отсутствуют, начните обсуждение!",
    "No more messages" : "Сообщений нет",
    "Retry" : "Повторить",
    "Failed to mark comments as read" : "Не удалось пометить комментарии как прочитанные",
    "Unable to load the comments list" : "Невозможно загрузить список комментариев",
    "_1 new comment_::_{unread} new comments_" : ["1 новый комментарий","{unread} новых комментариев","{unread} новых комментариев","{unread} новых комментариев"],
    "Comment" : "Комментарий",
    "An error occurred while trying to edit the comment" : "Попытка редактирования комментария завершилась ошибкой",
    "Comment deleted" : "Комментарий удалён",
    "An error occurred while trying to delete the comment" : "Попытка удаления комментария завершилась ошибкой",
    "An error occurred while trying to create the comment" : "Попытка создания комментария завершилась ошибкой",
    "_%n unread comment_::_%n unread comments_" : ["%n непрочитанный комментарий","%n непрочитанных комментариев","%n непрочитанных комментариев","%n непрочитанных комментариев"]
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
